###########################################################################
#
# win32.mak -- Windows Makefile for runtime-src\src\recpt
#
# By Michael Dewsnip
#
# Copyright (C) 2010  DL Consulting Ltd.
#
###########################################################################


RUNTIME_SRC_DIR = ..\..
GSDL_DIR = $(RUNTIME_SRC_DIR)\..


# Programs compiled and their install directories
CGIBIN_DIR = "$(GSDL_DIR)\cgi-bin"
CGIBIN_PROGRAMS = library.cgi

# Program: library.cgi
LIBRARY_CGI_CPPFLAGS = \
	-I"$(GSDL_DIR)\common-src\src\lib" \
	-I"$(GSDL_DIR)\runtime-src\src\colservr" \
	-I"$(GSDL_DIR)\runtime-src\src\protocol" \
	-I"$(GSDL_DIR)\common-src\packages\windows\crypt\crypt"

# Option: Lucene support (enabled by default)
ENABLE_LUCENE = 1
!IF $(ENABLE_LUCENE)
LIBRARY_CGI_CPPFLAGS = -DENABLE_LUCENE $(LIBRARY_CGI_CPPFLAGS)
!ENDIF

# Option: SQLite support (enabled by default)
USE_SQLITE = 1
!IF $(USE_SQLITE)
LIBRARY_CGI_CPPFLAGS = -DUSE_SQLITE $(LIBRARY_CGI_CPPFLAGS) -I"$(GSDL_DIR)\common-src\packages\sqlite\include"
!ENDIF

# Objects for library.cgi
LIBRARY_CGI_OBJECTS = \
	action.obj \
	argdb.obj \
	authenaction.obj \
	basequeryaction.obj \
	browseaction.obj \
	browseactiontools.obj \
	browserclass.obj \
	browsetoolsclass.obj \
	cgiargs.obj \
	cgiutils.obj \
	cgiwrapper.obj \
	collectoraction.obj \
	configaction.obj \
	converter.obj \
	datelistbrowserclass.obj \
	depositoraction.obj \
	documentaction.obj \
	dynamicclassifieraction.obj \
	extlinkaction.obj \
	formattools.obj \
	gtiaction.obj \
	highlighttext.obj \
	historydb.obj \
	hlistbrowserclass.obj \
	htmlbrowserclass.obj \
	htmlutils.obj \
	invbrowserclass.obj \
	librarymain.obj \
	maincfg.obj \
	pageaction.obj \
	pagedbrowserclass.obj \
	phindbrowserclass.obj \
	pingaction.obj \
	queryaction.obj \
	querytools.obj \
	receptionist.obj \
	sqlqueryaction.obj \
	statusaction.obj \
	string_pool.obj \
	tipaction.obj \
	userdb.obj \
	usersaction.obj \
	vlistbrowserclass.obj \
	wizardaction.obj

LIBRARY_CGI_LDADD = \
	"$(GSDL_DIR)\runtime-src\src\protocol\libgsdlprotocol.lib" \
	"$(GSDL_DIR)\runtime-src\src\colservr\libgsdlcolservr.lib" \
	"$(GSDL_DIR)\common-src\src\lib\libgsdllib.lib" \
	"$(GSDL_DIR)\common-src\packages\windows\crypt\crypt\crypt.lib"

# Option: Lucene support (enabled by default)
ENABLE_LUCENE = 1
!IF $(ENABLE_LUCENE)
LIBRARY_CGI_LDADD = $(LIBRARY_CGI_LDADD) "$(GSDL_DIR)\common-src\packages\expat\lib\libexpat.lib"
!ENDIF

# Option: SQLite support (enabled by default)
USE_SQLITE = 1
!IF $(USE_SQLITE)
LIBRARY_CGI_LDADD = $(LIBRARY_CGI_LDADD) "$(GSDL_DIR)\common-src\packages\sqlite\lib\sqlite3.lib"
!ENDIF


COMPILE = $(CPP) -nologo -c -EHsc -D__WIN32__ -DXML_STATIC -D_CRT_SECURE_NO_DEPRECATE $(LIBRARY_CGI_CPPFLAGS)
LINK = $(CPP) -nologo -Fe"$@" 

.SUFFIXES:
.SUFFIXES: .cpp .obj

.cpp.obj:
	$(COMPILE) $<


library.cgi: $(LIBRARY_CGI_OBJECTS) $(LIBRARY_CGI_LDADD)
	$(LINK) $(LIBRARY_CGI_OBJECTS) $(LIBRARY_CGI_LDADD)

all: $(CGIBIN_PROGRAMS)

install: $(CGIBIN_PROGRAMS)
	copy $(CGIBIN_PROGRAMS) $(CGIBIN_DIR)

clean:
	if EXIST *.obj del *.obj
	if EXIST $(CGIBIN_PROGRAMS) del $(CGIBIN_PROGRAMS)
